<p align="center">
  <a href="https://mahimailabs.github.io/fluxcrud/">
    <img src="https://github.com/mahimailabs/fluxcrud/blob/main/assets/logo.png?raw=true"  width="45%" height="auto">
  </a>
</p>
